/************************************************************************/
/*                                                                      */
/*  This program shows you how to perform a timed analog acquisition    */
/*  using AIAcquireWaveforms() and plot the results to a graph.         */                                                      
/*  The acquisition and plotting is performed in AcquireCallback().     */
/*                                                                      */
/************************************************************************/

#include <cvirte.h>    /* Needed if linking in external compiler; harmless otherwise */
#include <ansi_c.h>
#include <userint.h>
#include "ai^acq.h"
#include "easyio.h"

#define NUM_SCANS    100
#define UPPER_LIMIT  5.0
#define LOWER_LIMIT -5.0
#define SCAN_RATE    2000.0
#define MAX_CHANNELS 8

static int            panelHandle;
static short          device;
static unsigned long  numChannels;
static char           channelString[100];
static double         waveforms[MAX_CHANNELS*NUM_SCANS];

static int ColorArray[8] = {VAL_GREEN, VAL_YELLOW, VAL_CYAN, VAL_WHITE, VAL_BLUE, VAL_MAGENTA, VAL_GRAY, VAL_RED};

int main (int argc, char *argv[])
{
    if (InitCVIRTE (0, argv, 0) == 0)    /* Needed if linking in external compiler; harmless otherwise */
        return -1;    /* out of memory */
    
    panelHandle = LoadPanel (0, "ai^acq.uir", PANEL);
    DisplayPanel (panelHandle);
    RunUserInterface ();

    return 0;
}



/************************************************************************/
/*                                                                      */
/*  This callback function acquires and plots the data.                 */
/*                                                                      */
/************************************************************************/

int CVICALLBACK AcquireCallback (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    double actualRate;
    int i;
    
    switch (event) {
        case EVENT_COMMIT:
            GetCtrlVal (panelHandle, PANEL_CHANNEL, channelString);
            GetCtrlVal (panelHandle, PANEL_DEVICE, &device);
            GetNumChannels (device, channelString, ANALOG_INPUT, &numChannels);
            if (numChannels > MAX_CHANNELS)
            {
                MessagePopup ("", "Too many channels for this example.");
                return 0;
            }
            
            AIAcquireWaveforms (device, channelString, NUM_SCANS, SCAN_RATE,
                                  UPPER_LIMIT, LOWER_LIMIT, &actualRate, GROUP_BY_CHANNEL, 
                                  waveforms);
            
            DeleteGraphPlot (panelHandle, PANEL_GRAPH, -1,
                             VAL_DELAYED_DRAW);
            
            for (i=0; i<numChannels; i++)
            {
                
                PlotY (panelHandle, PANEL_GRAPH, &waveforms[NUM_SCANS*i], 
                        NUM_SCANS, VAL_DOUBLE,VAL_THIN_LINE, 
                        VAL_EMPTY_SQUARE, VAL_SOLID, 1, ColorArray[i]);
            }
            break;
    }
    return 0;
}


int CVICALLBACK QuitCallback (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event) {
        case EVENT_COMMIT:
            QuitUserInterface (0);
            break;
    }
    return 0;
}
