/************************************************************************/
/*                                                                      */
/*  This program shows you how to read analog input channels using      */
/*  AISampleChannels() and plot the results to a strip chart.           */
/*  The acquisition and plotting is performed in TimerCallback().       */
/*                                                                      */
/************************************************************************/

#include <cvirte.h>    /* Needed if linking in external compiler; harmless otherwise */
#include <userint.h>
#include <utility.h>
#include <ansi_c.h>
#include <easyio.h>
#include "ai^samp.h"

#define UPPER_LIMIT  5.0
#define LOWER_LIMIT -5.0

                                
static int            panelHandle;
static short          device;
static unsigned long  numChannels;
static char           channelString[100];
static double         voltages[100];

int main (int argc, char *argv[])
{
    if (InitCVIRTE (0, argv, 0) == 0)    /* Needed if linking in external compiler; harmless otherwise */
        return -1;    /* out of memory */
    
    panelHandle = LoadPanel (0, "ai^samp.uir", PANEL);
    DisplayPanel (panelHandle);
    RunUserInterface ();

    return 0;
}


int CVICALLBACK StartCallback (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    int error;
    
    switch (event) {
        case EVENT_COMMIT:
            GetCtrlVal (panelHandle, PANEL_DEVICE, &device);
            GetCtrlVal (panelHandle, PANEL_CHANNEL, channelString);
            
            error = GetNumChannels (device, channelString, ANALOG_INPUT, 
                                &numChannels);
            
            
            SetCtrlAttribute (panelHandle, PANEL_STRIPCHART, 
                                ATTR_NUM_TRACES, numChannels);
            SetCtrlAttribute (panelHandle, PANEL_DEVICE, ATTR_DIMMED, 1);
            SetCtrlAttribute (panelHandle, PANEL_CHANNEL, ATTR_DIMMED, 1);
            SetCtrlAttribute (panelHandle, PANEL_TIMER, ATTR_ENABLED, 1);
            
            break;
    }
    return 0;
}

int CVICALLBACK StopCallback (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    int error;
    
    switch (event) {
        case EVENT_COMMIT:
            SetCtrlAttribute (panelHandle, PANEL_DEVICE, ATTR_DIMMED, 0);
            SetCtrlAttribute (panelHandle, PANEL_CHANNEL, ATTR_DIMMED, 0);
            SetCtrlAttribute (panelHandle, PANEL_TIMER, ATTR_ENABLED, 0);
            
            break;
    }
    return 0;
}


int CVICALLBACK TimerCallback (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    short error;
    
    switch (event) {
        case EVENT_TIMER_TICK:
            error = AISampleChannels (device, channelString, UPPER_LIMIT, LOWER_LIMIT, 
                                voltages);
            PlotStripChart (panelHandle, PANEL_STRIPCHART, voltages,
                            numChannels, 0, 0, VAL_DOUBLE);
            
            
            break;
    }
    return 0;
}


int CVICALLBACK QuitCallback (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event) {
        case EVENT_COMMIT:
            QuitUserInterface (0);
            break;
    }
    return 0;
}


